@@ -1,18 +1,20 @@
 package org.sqlite;
 
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URISyntaxException;
 import java.net.URL;
+import java.nio.file.Files;
+import java.nio.file.StandardCopyOption;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.Properties;
 import java.util.concurrent.Executor;
+import org.sqlite.SQLiteConfig.TransactionMode;
 import org.sqlite.core.CoreDatabaseMetaData;
 import org.sqlite.core.DB;
 import org.sqlite.core.NativeDB;
@@ -25,6 +27,9 @@ public abstract class SQLiteConnection implements Connection {
     private CoreDatabaseMetaData meta = null;
     private final SQLiteConnectionConfig connectionConfig;
 
+    private TransactionMode currentTransactionMode;
+    private boolean firstStatementExecuted = false;
+
     /**
      * Connection constructor for reusing an existing DB handle
      *
@@ -61,6 +66,9 @@ public abstract class SQLiteConnection implements Connection {
             SQLiteConfig config = this.db.getConfig();
             this.connectionConfig = this.db.getConfig().newConnectionConfig();
             config.apply(this);
+            this.currentTransactionMode = this.getDatabase().getConfig().getTransactionMode();
+            // connection starts in "clean" state (even though some PRAGMA statements were executed)
+            this.firstStatementExecuted = false;
         } catch (Throwable t) {
             try {
                 if (newDB != null) {
@@ -73,6 +81,22 @@ public abstract class SQLiteConnection implements Connection {
         }
     }
 
+    public TransactionMode getCurrentTransactionMode() {
+        return this.currentTransactionMode;
+    }
+
+    public void setCurrentTransactionMode(final TransactionMode currentTransactionMode) {
+        this.currentTransactionMode = currentTransactionMode;
+    }
+
+    public void setFirstStatementExecuted(final boolean firstStatementExecuted) {
+        this.firstStatementExecuted = firstStatementExecuted;
+    }
+
+    public boolean isFirstStatementExecuted() {
+        return firstStatementExecuted;
+    }
+
     public SQLiteConnectionConfig getConnectionConfig() {
         return connectionConfig;
     }
@@ -147,7 +171,7 @@ public abstract class SQLiteConnection implements Connection {
      *
      * @param mode One of {@link SQLiteConfig.TransactionMode}
      * @see <a
-     *     href="http://www.sqlite.org/lang_transaction.html">http://www.sqlite.org/lang_transaction.html</a>
+     *     href="https://www.sqlite.org/lang_transaction.html">https://www.sqlite.org/lang_transaction.html</a>
      */
     protected void setTransactionMode(SQLiteConfig.TransactionMode mode) {
         connectionConfig.setTransactionMode(mode);
@@ -188,7 +212,7 @@ public abstract class SQLiteConnection implements Connection {
      * Opens a connection to the database using an SQLite library. * @throws SQLException
      *
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/c_open_autoproxy.html">http://www.sqlite.org/c3ref/c_open_autoproxy.html</a>
+     *     href="https://www.sqlite.org/c3ref/c_open_autoproxy.html">https://www.sqlite.org/c3ref/c_open_autoproxy.html</a>
      */
     private static DB open(String url, String origFileName, Properties props) throws SQLException {
         // Create a copy of the given properties
@@ -306,18 +330,9 @@ public abstract class SQLiteConnection implements Connection {
             //            }
         }
 
-        byte[] buffer = new byte[8192]; // 8K buffer
-        FileOutputStream writer = new FileOutputStream(dbFile);
-        InputStream reader = resourceAddr.openStream();
-        try {
-            int bytesRead = 0;
-            while ((bytesRead = reader.read(buffer)) != -1) {
-                writer.write(buffer, 0, bytesRead);
-            }
+        try (InputStream reader = resourceAddr.openStream()) {
+            Files.copy(reader, dbFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
             return dbFile;
-        } finally {
-            writer.close();
-            reader.close();
         }
     }
 
@@ -340,15 +355,21 @@ public abstract class SQLiteConnection implements Connection {
         if (connectionConfig.isAutoCommit() == ac) return;
 
         connectionConfig.setAutoCommit(ac);
-        db.exec(
-                connectionConfig.isAutoCommit() ? "commit;" : connectionConfig.transactionPrefix(),
-                ac);
+        // db.exec(connectionConfig.isAutoCommit() ? "commit;" : this.transactionPrefix(), ac);
+
+        if (this.getConnectionConfig().isAutoCommit()) {
+            db.exec("commit;", ac);
+            this.currentTransactionMode = null;
+        } else {
+            db.exec(this.transactionPrefix(), ac);
+            this.currentTransactionMode = this.getConnectionConfig().getTransactionMode();
+        }
     }
 
     /**
      * @return The busy timeout value for the connection.
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/busy_timeout.html">http://www.sqlite.org/c3ref/busy_timeout.html</a>
+     *     href="https://www.sqlite.org/c3ref/busy_timeout.html">https://www.sqlite.org/c3ref/busy_timeout.html</a>
      */
     public int getBusyTimeout() {
         return db.getConfig().getBusyTimeout();
@@ -359,7 +380,7 @@ public abstract class SQLiteConnection implements Connection {
      * off all busy handlers.
      *
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/busy_timeout.html">http://www.sqlite.org/c3ref/busy_timeout.html</a>
+     *     href="https://www.sqlite.org/c3ref/busy_timeout.html">https://www.sqlite.org/c3ref/busy_timeout.html</a>
      * @param timeoutMillis The timeout value in milliseconds.
      * @throws SQLException
      */
@@ -407,7 +428,7 @@ public abstract class SQLiteConnection implements Connection {
      * @return Compile-time library version numbers.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/c_source_id.html">http://www.sqlite.org/c3ref/c_source_id.html</a>
+     *     href="https://www.sqlite.org/c3ref/c_source_id.html">https://www.sqlite.org/c3ref/c_source_id.html</a>
      */
     public String libversion() throws SQLException {
         checkOpen();
@@ -421,7 +442,9 @@ public abstract class SQLiteConnection implements Connection {
         checkOpen();
         if (connectionConfig.isAutoCommit()) throw new SQLException("database in auto-commit mode");
         db.exec("commit;", getAutoCommit());
-        db.exec(connectionConfig.transactionPrefix(), getAutoCommit());
+        db.exec(this.transactionPrefix(), getAutoCommit());
+        this.firstStatementExecuted = false;
+        this.setCurrentTransactionMode(this.getConnectionConfig().getTransactionMode());
     }
 
     /** @see java.sql.Connection#rollback() */
@@ -430,7 +453,9 @@ public abstract class SQLiteConnection implements Connection {
         checkOpen();
         if (connectionConfig.isAutoCommit()) throw new SQLException("database in auto-commit mode");
         db.exec("rollback;", getAutoCommit());
-        db.exec(connectionConfig.transactionPrefix(), getAutoCommit());
+        db.exec(this.transactionPrefix(), getAutoCommit());
+        this.firstStatementExecuted = false;
+        this.setCurrentTransactionMode(this.getConnectionConfig().getTransactionMode());
     }
 
     /**
@@ -535,4 +560,8 @@ public abstract class SQLiteConnection implements Connection {
         final String newFilename = sb.toString();
         return newFilename;
     }
+
+    protected String transactionPrefix() {
+        return this.connectionConfig.transactionPrefix();
+    }
 }
