@@ -85,29 +85,29 @@ public abstract class DB implements Codes {
      *
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/interrupt.html">http://www.sqlite.org/c3ref/interrupt.html</a>
+     *     href="https://www.sqlite.org/c3ref/interrupt.html">https://www.sqlite.org/c3ref/interrupt.html</a>
      */
     public abstract void interrupt() throws SQLException;
 
     /**
-     * Sets a <a href="http://www.sqlite.org/c3ref/busy_handler.html">busy handler</a> that sleeps
+     * Sets a <a href="https://www.sqlite.org/c3ref/busy_handler.html">busy handler</a> that sleeps
      * for a specified amount of time when a table is locked.
      *
      * @param ms Time to sleep in milliseconds.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/busy_timeout.html">http://www.sqlite.org/c3ref/busy_timeout.html</a>
+     *     href="https://www.sqlite.org/c3ref/busy_timeout.html">https://www.sqlite.org/c3ref/busy_timeout.html</a>
      */
     public abstract void busy_timeout(int ms) throws SQLException;
 
     /**
-     * Sets a <a href="http://www.sqlite.org/c3ref/busy_handler.html">busy handler</a> that sleeps
+     * Sets a <a href="https://www.sqlite.org/c3ref/busy_handler.html">busy handler</a> that sleeps
      * for a specified amount of time when a table is locked.
      *
      * @param busyHandler
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/busy_handler.html">http://www.sqlite.org/c3ref/busy_timeout.html</a>
+     *     href="https://www.sqlite.org/c3ref/busy_handler.html">https://www.sqlite.org/c3ref/busy_timeout.html</a>
      */
     public abstract void busy_handler(BusyHandler busyHandler) throws SQLException;
 
@@ -117,7 +117,7 @@ public abstract class DB implements Codes {
      * @return Error description in English.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/errcode.html">http://www.sqlite.org/c3ref/errcode.html</a>
+     *     href="https://www.sqlite.org/c3ref/errcode.html">https://www.sqlite.org/c3ref/errcode.html</a>
      */
     abstract String errmsg() throws SQLException;
 
@@ -128,9 +128,9 @@ public abstract class DB implements Codes {
      * @return Compile-time SQLite version information.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/libversion.html">http://www.sqlite.org/c3ref/libversion.html</a>
+     *     href="https://www.sqlite.org/c3ref/libversion.html">https://www.sqlite.org/c3ref/libversion.html</a>
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/c_source_id.html">http://www.sqlite.org/c3ref/c_source_id.html</a>
+     *     href="https://www.sqlite.org/c3ref/c_source_id.html">https://www.sqlite.org/c3ref/c_source_id.html</a>
      */
     public abstract String libversion() throws SQLException;
 
@@ -138,28 +138,28 @@ public abstract class DB implements Codes {
      * @return Number of rows that were changed, inserted or deleted by the last SQL statement
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/changes.html">http://www.sqlite.org/c3ref/changes.html</a>
+     *     href="https://www.sqlite.org/c3ref/changes.html">https://www.sqlite.org/c3ref/changes.html</a>
      */
-    public abstract int changes() throws SQLException;
+    public abstract long changes() throws SQLException;
 
     /**
      * @return Number of row changes caused by INSERT, UPDATE or DELETE statements since the
      *     database connection was opened.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/total_changes.html">http://www.sqlite.org/c3ref/total_changes.html</a>
+     *     href="https://www.sqlite.org/c3ref/total_changes.html">https://www.sqlite.org/c3ref/total_changes.html</a>
      */
-    public abstract int total_changes() throws SQLException;
+    public abstract long total_changes() throws SQLException;
 
     /**
      * Enables or disables the sharing of the database cache and schema data structures between
      * connections to the same database.
      *
      * @param enable True to enable; false otherwise.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/enable_shared_cache.html">http://www.sqlite.org/c3ref/enable_shared_cache.html</a>
+     *     href="https://www.sqlite.org/c3ref/enable_shared_cache.html">https://www.sqlite.org/c3ref/enable_shared_cache.html</a>
      * @see org.sqlite.SQLiteErrorCode
      */
     public abstract int shared_cache(boolean enable) throws SQLException;
@@ -168,10 +168,10 @@ public abstract class DB implements Codes {
      * Enables or disables loading of SQLite extensions.
      *
      * @param enable True to enable; false otherwise.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/load_extension.html">http://www.sqlite.org/c3ref/load_extension.html</a>
+     *     href="https://www.sqlite.org/c3ref/load_extension.html">https://www.sqlite.org/c3ref/load_extension.html</a>
      */
     public abstract int enable_load_extension(boolean enable) throws SQLException;
 
@@ -182,7 +182,7 @@ public abstract class DB implements Codes {
      * @param sql SQL statement to be executed.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/exec.html">http://www.sqlite.org/c3ref/exec.html</a>
+     *     href="https://www.sqlite.org/c3ref/exec.html">https://www.sqlite.org/c3ref/exec.html</a>
      */
     public final synchronized void exec(String sql, boolean autoCommit) throws SQLException {
         SafeStmtPtr pointer = prepare(sql);
@@ -207,10 +207,10 @@ public abstract class DB implements Codes {
      *
      * @param file The database.
      * @param openFlags File opening configurations (<a
-     *     href="http://www.sqlite.org/c3ref/c_open_autoproxy.html">http://www.sqlite.org/c3ref/c_open_autoproxy.html</a>)
+     *     href="https://www.sqlite.org/c3ref/c_open_autoproxy.html">https://www.sqlite.org/c3ref/c_open_autoproxy.html</a>)
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/open.html">http://www.sqlite.org/c3ref/open.html</a>
+     *     href="https://www.sqlite.org/c3ref/open.html">https://www.sqlite.org/c3ref/open.html</a>
      */
     public final synchronized void open(String file, int openFlags) throws SQLException {
         _open(file, openFlags);
@@ -230,7 +230,7 @@ public abstract class DB implements Codes {
      *
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/close.html">http://www.sqlite.org/c3ref/close.html</a>
+     *     href="https://www.sqlite.org/c3ref/close.html">https://www.sqlite.org/c3ref/close.html</a>
      */
     public final synchronized void close() throws SQLException {
         // finalize any remaining statements before closing db
@@ -238,9 +238,6 @@ public abstract class DB implements Codes {
             element.close();
         }
 
-        // remove memory used by user-defined functions
-        free_functions();
-
         // clean up commit object
         if (begin != null) begin.close();
         if (commit != null) commit.close();
@@ -255,7 +252,7 @@ public abstract class DB implements Codes {
      * @param stmt The SQL statement to compile.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/prepare.html">http://www.sqlite.org/c3ref/prepare.html</a>
+     *     href="https://www.sqlite.org/c3ref/prepare.html">https://www.sqlite.org/c3ref/prepare.html</a>
      */
     public final synchronized void prepare(CoreStatement stmt) throws SQLException {
         if (stmt.sql == null) {
@@ -276,10 +273,10 @@ public abstract class DB implements Codes {
      *
      * @param safePtr the pointer wrapper to remove from internal structures
      * @param ptr the raw pointer to free
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException if finalization fails
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/finalize.html">http://www.sqlite.org/c3ref/finalize.html</a>
+     *     href="https://www.sqlite.org/c3ref/finalize.html">https://www.sqlite.org/c3ref/finalize.html</a>
      */
     public synchronized int finalize(SafeStmtPtr safePtr, long ptr) throws SQLException {
         try {
@@ -294,10 +291,10 @@ public abstract class DB implements Codes {
      *
      * @param filename The database to open.
      * @param openFlags File opening configurations (<a
-     *     href="http://www.sqlite.org/c3ref/c_open_autoproxy.html">http://www.sqlite.org/c3ref/c_open_autoproxy.html</a>)
+     *     href="https://www.sqlite.org/c3ref/c_open_autoproxy.html">https://www.sqlite.org/c3ref/c_open_autoproxy.html</a>)
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/open.html">http://www.sqlite.org/c3ref/open.html</a>
+     *     href="https://www.sqlite.org/c3ref/open.html">https://www.sqlite.org/c3ref/open.html</a>
      */
     protected abstract void _open(String filename, int openFlags) throws SQLException;
 
@@ -306,7 +303,7 @@ public abstract class DB implements Codes {
      *
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/close.html">http://www.sqlite.org/c3ref/close.html</a>
+     *     href="https://www.sqlite.org/c3ref/close.html">https://www.sqlite.org/c3ref/close.html</a>
      */
     protected abstract void _close() throws SQLException;
 
@@ -314,10 +311,10 @@ public abstract class DB implements Codes {
      * Complies, evaluates, executes and commits an SQL statement.
      *
      * @param sql An SQL statement.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/exec.html">http://www.sqlite.org/c3ref/exec.html</a>
+     *     href="https://www.sqlite.org/c3ref/exec.html">https://www.sqlite.org/c3ref/exec.html</a>
      */
     public abstract int _exec(String sql) throws SQLException;
 
@@ -325,10 +322,10 @@ public abstract class DB implements Codes {
      * Complies an SQL statement.
      *
      * @param sql An SQL statement.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/prepare.html">http://www.sqlite.org/c3ref/prepare.html</a>
+     *     href="https://www.sqlite.org/c3ref/prepare.html">https://www.sqlite.org/c3ref/prepare.html</a>
      */
     protected abstract SafeStmtPtr prepare(String sql) throws SQLException;
 
@@ -336,10 +333,10 @@ public abstract class DB implements Codes {
      * Destroys a prepared statement.
      *
      * @param stmt Pointer to the statement pointer.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/finalize.html">http://www.sqlite.org/c3ref/finalize.html</a>
+     *     href="https://www.sqlite.org/c3ref/finalize.html">https://www.sqlite.org/c3ref/finalize.html</a>
      */
     protected abstract int finalize(long stmt) throws SQLException;
 
@@ -347,10 +344,10 @@ public abstract class DB implements Codes {
      * Evaluates a statement.
      *
      * @param stmt Pointer to the statement.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/step.html">http://www.sqlite.org/c3ref/step.html</a>
+     *     href="https://www.sqlite.org/c3ref/step.html">https://www.sqlite.org/c3ref/step.html</a>
      */
     public abstract int step(long stmt) throws SQLException;
 
@@ -358,10 +355,10 @@ public abstract class DB implements Codes {
      * Sets a prepared statement object back to its initial state, ready to be re-executed.
      *
      * @param stmt Pointer to the statement.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/reset.html">http://www.sqlite.org/c3ref/reset.html</a>
+     *     href="https://www.sqlite.org/c3ref/reset.html">https://www.sqlite.org/c3ref/reset.html</a>
      */
     public abstract int reset(long stmt) throws SQLException;
 
@@ -369,10 +366,10 @@ public abstract class DB implements Codes {
      * Reset all bindings on a prepared statement (reset all host parameters to NULL).
      *
      * @param stmt Pointer to the statement.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/clear_bindings.html">http://www.sqlite.org/c3ref/clear_bindings.html</a>
+     *     href="https://www.sqlite.org/c3ref/clear_bindings.html">https://www.sqlite.org/c3ref/clear_bindings.html</a>
      */
     public abstract int clear_bindings(long stmt) throws SQLException; // TODO remove?
 
@@ -381,7 +378,7 @@ public abstract class DB implements Codes {
      * @return Number of parameters in a prepared SQL.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_parameter_count.html">http://www.sqlite.org/c3ref/bind_parameter_count.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_parameter_count.html">https://www.sqlite.org/c3ref/bind_parameter_count.html</a>
      */
     abstract int bind_parameter_count(long stmt) throws SQLException;
 
@@ -390,7 +387,7 @@ public abstract class DB implements Codes {
      * @return Number of columns in the result set returned by the prepared statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_count.html">http://www.sqlite.org/c3ref/column_count.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_count.html">https://www.sqlite.org/c3ref/column_count.html</a>
      */
     public abstract int column_count(long stmt) throws SQLException;
 
@@ -400,7 +397,7 @@ public abstract class DB implements Codes {
      * @return Datatype code for the initial data type of the result column.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract int column_type(long stmt, int col) throws SQLException;
 
@@ -410,7 +407,7 @@ public abstract class DB implements Codes {
      * @return Declared type of the table column for prepared statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_decltype.html">http://www.sqlite.org/c3ref/column_decltype.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_decltype.html">https://www.sqlite.org/c3ref/column_decltype.html</a>
      */
     public abstract String column_decltype(long stmt, int col) throws SQLException;
 
@@ -420,7 +417,7 @@ public abstract class DB implements Codes {
      * @return Original text of column name which is the declared in the CREATE TABLE statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_database_name.html">http://www.sqlite.org/c3ref/column_database_name.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_database_name.html">https://www.sqlite.org/c3ref/column_database_name.html</a>
      */
     public abstract String column_table_name(long stmt, int col) throws SQLException;
 
@@ -430,7 +427,7 @@ public abstract class DB implements Codes {
      * @return Name assigned to a particular column in the result set of a SELECT statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_name.html">http://www.sqlite.org/c3ref/column_name.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_name.html">https://www.sqlite.org/c3ref/column_name.html</a>
      */
     public abstract String column_name(long stmt, int col) throws SQLException;
 
@@ -440,7 +437,7 @@ public abstract class DB implements Codes {
      * @return Value of the column as text data type in the result set of a SELECT statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract String column_text(long stmt, int col) throws SQLException;
 
@@ -450,7 +447,7 @@ public abstract class DB implements Codes {
      * @return BLOB value of the column in the result set of a SELECT statement
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract byte[] column_blob(long stmt, int col) throws SQLException;
 
@@ -460,7 +457,7 @@ public abstract class DB implements Codes {
      * @return DOUBLE value of the column in the result set of a SELECT statement
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract double column_double(long stmt, int col) throws SQLException;
 
@@ -470,7 +467,7 @@ public abstract class DB implements Codes {
      * @return LONG value of the column in the result set of a SELECT statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract long column_long(long stmt, int col) throws SQLException;
 
@@ -480,7 +477,7 @@ public abstract class DB implements Codes {
      * @return INT value of column in the result set of a SELECT statement.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/column_blob.html">http://www.sqlite.org/c3ref/column_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/column_blob.html">https://www.sqlite.org/c3ref/column_blob.html</a>
      */
     public abstract int column_int(long stmt, int col) throws SQLException;
 
@@ -490,7 +487,7 @@ public abstract class DB implements Codes {
      *
      * @param stmt Pointer to the statement.
      * @param pos The index of the SQL parameter to be set to NULL.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      */
     abstract int bind_null(long stmt, int pos) throws SQLException;
@@ -502,10 +499,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos The index of the SQL parameter to be set.
      * @param v Value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     abstract int bind_int(long stmt, int pos, int v) throws SQLException;
 
@@ -516,10 +513,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos The index of the SQL parameter to be set.
      * @param v Value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     abstract int bind_long(long stmt, int pos, long v) throws SQLException;
 
@@ -530,10 +527,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos Index of the SQL parameter to be set.
      * @param v Value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     abstract int bind_double(long stmt, int pos, double v) throws SQLException;
 
@@ -544,10 +541,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos Index of the SQL parameter to be set.
      * @param v value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     abstract int bind_text(long stmt, int pos, String v) throws SQLException;
 
@@ -558,10 +555,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos Index of the SQL parameter to be set.
      * @param v Value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     abstract int bind_blob(long stmt, int pos, byte[] v) throws SQLException;
 
@@ -571,7 +568,7 @@ public abstract class DB implements Codes {
      * @param context Pointer to the SQLite database context.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_null(long context) throws SQLException;
 
@@ -583,7 +580,7 @@ public abstract class DB implements Codes {
      * @param val Result value of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_text(long context, String val) throws SQLException;
 
@@ -595,7 +592,7 @@ public abstract class DB implements Codes {
      * @param val Result value of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_blob(long context, byte[] val) throws SQLException;
 
@@ -607,7 +604,7 @@ public abstract class DB implements Codes {
      * @param val Result value of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_double(long context, double val) throws SQLException;
 
@@ -619,7 +616,7 @@ public abstract class DB implements Codes {
      * @param val Result value of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_long(long context, long val) throws SQLException;
 
@@ -631,7 +628,7 @@ public abstract class DB implements Codes {
      * @param val Result value of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_int(long context, int val) throws SQLException;
 
@@ -643,7 +640,7 @@ public abstract class DB implements Codes {
      * @param err Error result of an SQL function.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/result_blob.html">http://www.sqlite.org/c3ref/result_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/result_blob.html">https://www.sqlite.org/c3ref/result_blob.html</a>
      */
     public abstract void result_error(long context, String err) throws SQLException;
 
@@ -653,7 +650,7 @@ public abstract class DB implements Codes {
      * @return Parameter value of the given SQLite function or aggregate in text data type.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract String value_text(Function f, int arg) throws SQLException;
 
@@ -663,7 +660,7 @@ public abstract class DB implements Codes {
      * @return Parameter value of the given SQLite function or aggregate in blob data type.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract byte[] value_blob(Function f, int arg) throws SQLException;
 
@@ -673,7 +670,7 @@ public abstract class DB implements Codes {
      * @return Parameter value of the given SQLite function or aggregate in double data type
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract double value_double(Function f, int arg) throws SQLException;
 
@@ -683,7 +680,7 @@ public abstract class DB implements Codes {
      * @return Parameter value of the given SQLite function or aggregate in long data type.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract long value_long(Function f, int arg) throws SQLException;
 
@@ -696,7 +693,7 @@ public abstract class DB implements Codes {
      * @return Parameter value of the given SQLite function or aggregate.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract int value_int(Function f, int arg) throws SQLException;
 
@@ -706,7 +703,7 @@ public abstract class DB implements Codes {
      * @return Parameter datatype of the function or aggregate in int data type.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/value_blob.html">http://www.sqlite.org/c3ref/value_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/value_blob.html">https://www.sqlite.org/c3ref/value_blob.html</a>
      */
     public abstract int value_type(Function f, int arg) throws SQLException;
 
@@ -717,10 +714,10 @@ public abstract class DB implements Codes {
      * @param f SQLite function object.
      * @param flags Extra flags to use when creating the function, such as {@link
      *     Function#FLAG_DETERMINISTIC}
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/create_function.html">http://www.sqlite.org/c3ref/create_function.html</a>
+     *     href="https://www.sqlite.org/c3ref/create_function.html">https://www.sqlite.org/c3ref/create_function.html</a>
      */
     public abstract int create_function(String name, Function f, int nArgs, int flags)
             throws SQLException;
@@ -729,10 +726,10 @@ public abstract class DB implements Codes {
      * De-registers a user defined function
      *
      * @param name Name of the function to de-registered.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      */
-    public abstract int destroy_function(String name, int nArgs) throws SQLException;
+    public abstract int destroy_function(String name) throws SQLException;
 
     /**
      * Create a user defined collation with given collation name and the collation object.
@@ -755,33 +752,70 @@ public abstract class DB implements Codes {
      */
     public abstract int destroy_collation(String name) throws SQLException;
 
-    /**
-     * Unused as we use the user_data pointer to store a single word.
-     *
-     * @throws SQLException
-     */
-    abstract void free_functions() throws SQLException;
-
     /**
      * @param dbName Database name to be backed up.
      * @param destFileName Target backup file name.
      * @param observer ProgressObserver object.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      */
     public abstract int backup(String dbName, String destFileName, ProgressObserver observer)
             throws SQLException;
 
+    /**
+     * @param dbName Database name to be backed up.
+     * @param destFileName Target backup file name.
+     * @param observer ProgressObserver object.
+     * @param sleepTimeMillis time to wait during a backup/restore operation if sqlite3_backup_step
+     *     returns SQLITE_BUSY before continuing
+     * @param nTimeouts the number of times sqlite3_backup_step can return SQLITE_BUSY before
+     *     failing
+     * @param pagesPerStep the number of pages to copy in each sqlite3_backup_step. If this is
+     *     negative, the entire DB is copied at once.
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @throws SQLException
+     */
+    public abstract int backup(
+            String dbName,
+            String destFileName,
+            ProgressObserver observer,
+            int sleepTimeMillis,
+            int nTimeouts,
+            int pagesPerStep)
+            throws SQLException;
+
     /**
      * @param dbName Database name for restoring data.
      * @param sourceFileName Source file name.
      * @param observer ProgressObserver object.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      */
     public abstract int restore(String dbName, String sourceFileName, ProgressObserver observer)
             throws SQLException;
 
+    /**
+     * @param dbName the name of the db to restore
+     * @param sourceFileName the filename of the source db to restore
+     * @param observer ProgressObserver object.
+     * @param sleepTimeMillis time to wait during a backup/restore operation if sqlite3_backup_step
+     *     returns SQLITE_BUSY before continuing
+     * @param nTimeouts the number of times sqlite3_backup_step can return SQLITE_BUSY before
+     *     failing
+     * @param pagesPerStep the number of pages to copy in each sqlite3_backup_step. If this is
+     *     negative, the entire DB is copied at once.
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @throws SQLException
+     */
+    public abstract int restore(
+            String dbName,
+            String sourceFileName,
+            ProgressObserver observer,
+            int sleepTimeMillis,
+            int nTimeouts,
+            int pagesPerStep)
+            throws SQLException;
+
     /**
      * @param id The id of the limit.
      * @param value The new value of the limit.
@@ -838,10 +872,10 @@ public abstract class DB implements Codes {
      * @param stmt Pointer to the statement.
      * @param pos Index of the SQL parameter to be set to NULL.
      * @param v Value to bind to the parameter.
-     * @return <a href="http://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
+     * @return <a href="https://www.sqlite.org/c3ref/c_abort.html">Result Codes</a>
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/bind_blob.html">http://www.sqlite.org/c3ref/bind_blob.html</a>
+     *     href="https://www.sqlite.org/c3ref/bind_blob.html">https://www.sqlite.org/c3ref/bind_blob.html</a>
      */
     final synchronized int sqlbind(long stmt, int pos, Object v) throws SQLException {
         pos++;
@@ -877,13 +911,13 @@ public abstract class DB implements Codes {
      *     commands execute successfully;
      * @throws SQLException if statement is not open or is being used elsewhere
      */
-    final synchronized int[] executeBatch(
+    final synchronized long[] executeBatch(
             SafeStmtPtr stmt, int count, Object[] vals, boolean autoCommit) throws SQLException {
         return stmt.safeRun((db, ptr) -> this.executeBatch(ptr, count, vals, autoCommit));
     }
 
-    private synchronized int[] executeBatch(long stmt, int count, Object[] vals, boolean autoCommit)
-            throws SQLException {
+    private synchronized long[] executeBatch(
+            long stmt, int count, Object[] vals, boolean autoCommit) throws SQLException {
         if (count < 1) {
             throw new SQLException("count (" + count + ") < 1");
         }
@@ -891,7 +925,7 @@ public abstract class DB implements Codes {
         final int params = bind_parameter_count(stmt);
 
         int rc;
-        int[] changes = new int[count];
+        long[] changes = new long[count];
 
         try {
             for (int i = 0; i < count; i++) {
@@ -908,7 +942,11 @@ public abstract class DB implements Codes {
                     reset(stmt);
                     if (rc == SQLITE_ROW) {
                         throw new BatchUpdateException(
-                                "batch entry " + i + ": query returns results", changes);
+                                "batch entry " + i + ": query returns results",
+                                null,
+                                0,
+                                changes,
+                                null);
                     }
                     throwex(rc);
                 }
@@ -925,7 +963,7 @@ public abstract class DB implements Codes {
 
     /**
      * @see <a
-     *     href="http://www.sqlite.org/c_interface.html#sqlite_exec">http://www.sqlite.org/c_interface.html#sqlite_exec</a>
+     *     href="https://www.sqlite.org/c_interface.html#sqlite_exec">https://www.sqlite.org/c_interface.html#sqlite_exec</a>
      * @param stmt Stmt object.
      * @param vals Array of parameter values.
      * @return True if a row of ResultSet is ready; false otherwise.
@@ -983,7 +1021,7 @@ public abstract class DB implements Codes {
      * @return True if a row of ResultSet is ready; false otherwise.
      * @throws SQLException
      * @see <a
-     *     href="http://www.sqlite.org/c3ref/exec.html">http://www.sqlite.org/c3ref/exec.html</a>
+     *     href="https://www.sqlite.org/c3ref/exec.html">https://www.sqlite.org/c3ref/exec.html</a>
      */
     final synchronized boolean execute(String sql, boolean autoCommit) throws SQLException {
         int statusCode = _exec(sql);
@@ -1010,7 +1048,7 @@ public abstract class DB implements Codes {
      *     completed SQL.
      * @throws SQLException
      */
-    public final synchronized int executeUpdate(CoreStatement stmt, Object[] vals)
+    public final synchronized long executeUpdate(CoreStatement stmt, Object[] vals)
             throws SQLException {
         try {
             if (execute(stmt, vals)) {
