@@ -4,6 +4,7 @@ import java.sql.CallableStatement;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.SQLFeatureNotSupportedException;
 import java.sql.SQLWarning;
 import java.sql.Savepoint;
 import java.sql.Statement;
@@ -12,6 +13,8 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.atomic.AtomicInteger;
+import org.sqlite.SQLiteConfig;
+import org.sqlite.SQLiteConfig.TransactionMode;
 import org.sqlite.SQLiteConnection;
 import org.sqlite.SQLiteOpenMode;
 
@@ -19,10 +22,64 @@ public abstract class JDBC3Connection extends SQLiteConnection {
     private final AtomicInteger savePoint = new AtomicInteger(0);
     private Map<String, Class<?>> typeMap;
 
+    private boolean readOnly = false;
+
     protected JDBC3Connection(String url, String fileName, Properties prop) throws SQLException {
         super(url, fileName, prop);
     }
 
+    /**
+     * This will try to enforce the transaction mode if SQLiteConfig#isExplicitReadOnly is true and
+     * auto commit is disabled.
+     *
+     * <ul>
+     *   <li>If this connection is read only, the PRAGMA query_only will be set
+     *   <li>If this connection is not read only:
+     *       <ul>
+     *         <li>if no statement has been executed, PRAGMA query_only will be set to false, and an
+     *             IMMEDIATE transaction will be started
+     *         <li>if a statement has already been executed, an exception is thrown
+     *       </ul>
+     * </ul>
+     *
+     * @throws SQLException if a statement has already been executed on this connection, then the
+     *     transaction cannot be upgraded to write
+     */
+    @SuppressWarnings("deprecation")
+    public void tryEnforceTransactionMode() throws SQLException {
+        // important note: read-only mode is only supported when auto-commit is disabled
+        if (getDatabase().getConfig().isExplicitReadOnly()
+                && !this.getAutoCommit()
+                && this.getCurrentTransactionMode() != null) {
+            if (isReadOnly()) {
+                // this is a read-only transaction, make sure all writing operations are rejected by
+                // the DB
+                // (note: this pragma is evaluated on a per-transaction basis by SQLite)
+                getDatabase()._exec("PRAGMA query_only = true;");
+            } else {
+                if (getCurrentTransactionMode() == TransactionMode.DEFERRED
+                        || this.getCurrentTransactionMode() == TransactionMode.DEFFERED) {
+                    if (isFirstStatementExecuted()) {
+                        // first statement was already executed; cannot upgrade to write
+                        // transaction!
+                        throw new SQLException(
+                                "A statement has already been executed on this connection; cannot upgrade to write transaction");
+                    } else {
+                        // this is the first statement in the transaction; close and create an
+                        // immediate one
+                        getDatabase()._exec("commit; /* need to explicitly upgrade transaction */");
+
+                        // start the write transaction
+                        getDatabase()._exec("PRAGMA query_only = false;");
+                        getDatabase()
+                                ._exec("BEGIN IMMEDIATE; /* explicitly upgrade transaction */");
+                        setCurrentTransactionMode(TransactionMode.IMMEDIATE);
+                    }
+                }
+            }
+        }
+    }
+
     /** @see java.sql.Connection#getCatalog() */
     public String getCatalog() throws SQLException {
         checkOpen();
@@ -67,18 +124,32 @@ public abstract class JDBC3Connection extends SQLiteConnection {
     }
 
     /** @see java.sql.Connection#isReadOnly() */
-    public boolean isReadOnly() throws SQLException {
-        return (getDatabase().getConfig().getOpenModeFlags() & SQLiteOpenMode.READONLY.flag) != 0;
+    public boolean isReadOnly() {
+        SQLiteConfig config = getDatabase().getConfig();
+        return (
+        // the entire database is read-only
+        ((config.getOpenModeFlags() & SQLiteOpenMode.READONLY.flag) != 0)
+                // the flag was set explicitly by the user on this connection
+                || (config.isExplicitReadOnly() && this.readOnly));
     }
 
     /** @see java.sql.Connection#setReadOnly(boolean) */
     public void setReadOnly(boolean ro) throws SQLException {
-        // trying to change read-only flag
-        if (ro != isReadOnly()) {
-            throw new SQLException(
-                    "Cannot change read-only flag after establishing a connection."
-                            + " Use SQLiteConfig#setReadOnly and SQLiteConfig.createConnection().");
+        if (getDatabase().getConfig().isExplicitReadOnly()) {
+            if (ro != readOnly && isFirstStatementExecuted()) {
+                throw new SQLException(
+                        "Cannot change Read-Only status of this connection: the first statement was"
+                                + " already executed and the transaction is open.");
+            }
+        } else {
+            // trying to change read-only flag
+            if (ro != isReadOnly()) {
+                throw new SQLException(
+                        "Cannot change read-only flag after establishing a connection."
+                                + " Use SQLiteConfig#setReadOnly and SQLiteConfig.createConnection().");
+            }
         }
+        this.readOnly = ro;
     }
 
     /** @see java.sql.Connection#nativeSQL(java.lang.String) */
@@ -166,7 +237,7 @@ public abstract class JDBC3Connection extends SQLiteConnection {
             // when a SAVEPOINT is the outermost savepoint and not
             // with a BEGIN...COMMIT then the behavior is the same
             // as BEGIN DEFERRED TRANSACTION
-            // http://www.sqlite.org/lang_savepoint.html
+            // https://www.sqlite.org/lang_savepoint.html
             getConnectionConfig().setAutoCommit(false);
         }
         Savepoint sp = new JDBC3Savepoint(savePoint.incrementAndGet());
@@ -181,7 +252,7 @@ public abstract class JDBC3Connection extends SQLiteConnection {
             // when a SAVEPOINT is the outermost savepoint and not
             // with a BEGIN...COMMIT then the behavior is the same
             // as BEGIN DEFERRED TRANSACTION
-            // http://www.sqlite.org/lang_savepoint.html
+            // https://www.sqlite.org/lang_savepoint.html
             getConnectionConfig().setAutoCommit(false);
         }
         Savepoint sp = new JDBC3Savepoint(savePoint.incrementAndGet(), name);
@@ -211,9 +282,7 @@ public abstract class JDBC3Connection extends SQLiteConnection {
                         getAutoCommit());
     }
 
-    // UNUSED FUNCTIONS /////////////////////////////////////////////
-
     public Struct createStruct(String t, Object[] attr) throws SQLException {
-        throw new SQLException("unsupported by SQLite");
+        throw new SQLFeatureNotSupportedException("not implemented by SQLite JDBC driver");
     }
 }
