@@ -15,6 +15,7 @@ import java.sql.Ref;
 import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
+import java.sql.SQLFeatureNotSupportedException;
 import java.sql.Statement;
 import java.sql.Time;
 import java.sql.Timestamp;
@@ -43,14 +44,23 @@ public abstract class JDBC3PreparedStatement extends CorePreparedStatement {
         rs.close();
         pointer.safeRunConsume(DB::reset);
 
-        boolean success = false;
-        try {
-            resultsWaiting = conn.getDatabase().execute(this, batch);
-            success = true;
-            return 0 != columnCount;
-        } finally {
-            if (!success && !pointer.isClosed()) pointer.safeRunConsume(DB::reset);
+        if (this.conn instanceof JDBC3Connection) {
+            ((JDBC3Connection) this.conn).tryEnforceTransactionMode();
         }
+
+        return this.withConnectionTimeout(
+                () -> {
+                    boolean success = false;
+                    try {
+                        resultsWaiting =
+                                conn.getDatabase().execute(JDBC3PreparedStatement.this, batch);
+                        success = true;
+                        updateCount = getDatabase().changes();
+                        return 0 != columnCount;
+                    } finally {
+                        if (!success && !pointer.isClosed()) pointer.safeRunConsume(DB::reset);
+                    }
+                });
     }
 
     /** @see java.sql.PreparedStatement#executeQuery() */
@@ -64,20 +74,33 @@ public abstract class JDBC3PreparedStatement extends CorePreparedStatement {
         rs.close();
         pointer.safeRunConsume(DB::reset);
 
-        boolean success = false;
-        try {
-            resultsWaiting = conn.getDatabase().execute(this, batch);
-            success = true;
-        } finally {
-            if (!success && !pointer.isClosed()) {
-                pointer.safeRunInt(DB::reset);
-            }
+        if (this.conn instanceof JDBC3Connection) {
+            ((JDBC3Connection) this.conn).tryEnforceTransactionMode();
         }
-        return getResultSet();
+
+        return this.withConnectionTimeout(
+                () -> {
+                    boolean success = false;
+                    try {
+                        resultsWaiting =
+                                conn.getDatabase().execute(JDBC3PreparedStatement.this, batch);
+                        success = true;
+                    } finally {
+                        if (!success && !pointer.isClosed()) {
+                            pointer.safeRunInt(DB::reset);
+                        }
+                    }
+                    return getResultSet();
+                });
     }
 
     /** @see java.sql.PreparedStatement#executeUpdate() */
     public int executeUpdate() throws SQLException {
+        return (int) executeLargeUpdate();
+    }
+
+    /** @see java.sql.PreparedStatement#executeLargeUpdate() */
+    public long executeLargeUpdate() throws SQLException {
         checkOpen();
 
         if (columnCount != 0) {
@@ -87,7 +110,12 @@ public abstract class JDBC3PreparedStatement extends CorePreparedStatement {
         rs.close();
         pointer.safeRunConsume(DB::reset);
 
-        return conn.getDatabase().executeUpdate(this, batch);
+        if (this.conn instanceof JDBC3Connection) {
+            ((JDBC3Connection) this.conn).tryEnforceTransactionMode();
+        }
+
+        return this.withConnectionTimeout(
+                () -> conn.getDatabase().executeUpdate(JDBC3PreparedStatement.this, batch));
     }
 
     /** @see java.sql.PreparedStatement#addBatch() */
@@ -180,10 +208,7 @@ public abstract class JDBC3PreparedStatement extends CorePreparedStatement {
      */
     private byte[] readBytes(InputStream istream, int length) throws SQLException {
         if (length < 0) {
-            SQLException exception =
-                    new SQLException("Error reading stream. Length should be non-negative");
-
-            throw exception;
+            throw new SQLException("Error reading stream. Length should be non-negative");
         }
 
         byte[] bytes = new byte[length];
@@ -399,55 +424,97 @@ public abstract class JDBC3PreparedStatement extends CorePreparedStatement {
         return (ResultSetMetaData) rs;
     }
 
-    // UNUSED ///////////////////////////////////////////////////////
-    protected SQLException unused() {
-        return new SQLException("not implemented by SQLite JDBC driver");
+    protected SQLException unsupported() {
+        return new SQLFeatureNotSupportedException("not implemented by SQLite JDBC driver");
+    }
+
+    protected SQLException invalid() {
+        return new SQLException("method cannot be called on a PreparedStatement");
     }
 
     // PreparedStatement ////////////////////////////////////////////
 
     public void setArray(int i, Array x) throws SQLException {
-        throw unused();
+        throw unsupported();
     }
-    //    public void setBigDecimal(int parameterIndex, BigDecimal x)
-    //        throws SQLException { throw unused(); }
+
     public void setBlob(int i, Blob x) throws SQLException {
-        throw unused();
+        throw unsupported();
     }
 
     public void setClob(int i, Clob x) throws SQLException {
-        throw unused();
+        throw unsupported();
     }
 
     public void setRef(int i, Ref x) throws SQLException {
-        throw unused();
+        throw unsupported();
     }
 
     public void setURL(int pos, URL x) throws SQLException {
-        throw unused();
+        throw unsupported();
     }
 
     /** @see org.sqlite.core.CoreStatement#exec(java.lang.String) */
     @Override
     public boolean execute(String sql) throws SQLException {
-        throw unused();
+        throw invalid();
+    }
+
+    public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
+        throw invalid();
+    }
+
+    public boolean execute(String sql, int[] colinds) throws SQLException {
+        throw invalid();
+    }
+
+    public boolean execute(String sql, String[] colnames) throws SQLException {
+        throw invalid();
     }
 
     /** @see org.sqlite.core.CoreStatement#exec(java.lang.String) */
     @Override
     public int executeUpdate(String sql) throws SQLException {
-        throw unused();
+        throw invalid();
+    }
+
+    public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
+        throw invalid();
+    }
+
+    public int executeUpdate(String sql, int[] colinds) throws SQLException {
+        throw invalid();
+    }
+
+    public int executeUpdate(String sql, String[] cols) throws SQLException {
+        throw invalid();
+    }
+
+    public long executeLargeUpdate(String sql) throws SQLException {
+        throw invalid();
+    }
+
+    public long executeLargeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
+        throw invalid();
+    }
+
+    public long executeLargeUpdate(String sql, int[] colinds) throws SQLException {
+        throw invalid();
+    }
+
+    public long executeLargeUpdate(String sql, String[] cols) throws SQLException {
+        throw invalid();
     }
 
     /** @see org.sqlite.core.CoreStatement#exec(String) */
     @Override
     public ResultSet executeQuery(String sql) throws SQLException {
-        throw unused();
+        throw invalid();
     }
 
     /** */
     @Override
     public void addBatch(String sql) throws SQLException {
-        throw unused();
+        throw invalid();
     }
 }
