@@ -18,7 +18,11 @@ import java.util.Map;
 import java.util.Properties;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Nested;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.condition.DisabledInNativeImage;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 /** These tests are designed to stress Statements on memory databases. */
 public class DBMetaDataTest {
@@ -137,8 +141,8 @@ public class DBMetaDataTest {
 
         testTypeInfo(
                 rs,
-                "BLOB",
-                Types.BLOB,
+                "NULL",
+                Types.NULL,
                 0,
                 null,
                 null,
@@ -169,23 +173,6 @@ public class DBMetaDataTest {
                 0,
                 0,
                 10);
-        testTypeInfo(
-                rs,
-                "NULL",
-                Types.NULL,
-                0,
-                null,
-                null,
-                null,
-                DatabaseMetaData.typeNullable,
-                false,
-                DatabaseMetaData.typeSearchable,
-                true,
-                false,
-                false,
-                0,
-                0,
-                10);
         testTypeInfo(
                 rs,
                 "REAL",
@@ -220,6 +207,23 @@ public class DBMetaDataTest {
                 0,
                 0,
                 10);
+        testTypeInfo(
+                rs,
+                "BLOB",
+                Types.BLOB,
+                0,
+                null,
+                null,
+                null,
+                DatabaseMetaData.typeNullable,
+                false,
+                DatabaseMetaData.typeSearchable,
+                true,
+                false,
+                false,
+                0,
+                0,
+                10);
 
         assertThat(rs.next()).isFalse();
     }
@@ -373,6 +377,18 @@ public class DBMetaDataTest {
         assertThat(rs.next()).isFalse();
 
         rs = meta.getColumns(null, null, "%", "%");
+        // SYSTEM TABLE "sqlite_schema"
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("TABLE_NAME")).isEqualTo("sqlite_schema");
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("type");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("name");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("tbl_name");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("rootpage");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("sql");
         // TABLE "test"
         assertThat(rs.next()).isTrue();
         assertThat(rs.getString("TABLE_NAME")).isEqualTo("test");
@@ -402,6 +418,20 @@ public class DBMetaDataTest {
         rs = meta.getColumns(null, null, "doesnotexist", "%");
         assertThat(rs.next()).isFalse();
         assertThat(rs.getMetaData().getColumnCount()).isEqualTo(24);
+
+        rs = meta.getColumns(null, null, "sqlite_schema", "%");
+        // SYSTEM TABLE "sqlite_schema"
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("TABLE_NAME")).isEqualTo("sqlite_schema");
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("type");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("name");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("tbl_name");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("rootpage");
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getString("COLUMN_NAME")).isEqualTo("sql");
     }
 
     @Test
@@ -598,7 +628,7 @@ public class DBMetaDataTest {
         stat.executeUpdate(
                 "CREATE TABLE PTWO ( ID_FIRST_TWO INTEGER NOT NULL, ID_SECOND_TWO INTEGER NOT NULL, ADDITIONAL_TWO TEXT, CONSTRAINT PTWO_PK PRIMARY KEY (ID_FIRST_TWO, ID_SECOND_TWO) )");
         stat.executeUpdate(
-                "CREATE TABLE CHILD ( ID_CHILD INTEGER NOT NULL, ID_CHILD_TO_ONE INTEGER NOT NULL, ID_CHILD_TO_TWO INTEGER NOT NULL, CONSTRAINT CHILD_PK PRIMARY KEY (ID_CHILD, ID_CHILD_TO_ONE), CONSTRAINT PONE_FK01 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_ONE) REFERENCES PONE (ID_FIRST_ONE, ID_SECOND_ONE) ON DELETE CASCADE, CONSTRAINT PTWO_FK02 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_TWO) REFERENCES PTWO (ID_FIRST_TWO, ID_SECOND_TWO) )");
+                "CREATE TABLE CHILD ( ID_CHILD INTEGER NOT NULL, ID_CHILD_TO_ONE INTEGER NOT NULL, ID_CHILD_TO_TWO INTEGER NOT NULL, CONSTRAINT CHILD_PK PRIMARY KEY (ID_CHILD, ID_CHILD_TO_ONE), CONSTRAINT \"PONE_FK01\" FOREIGN KEY (ID_CHILD, ID_CHILD_TO_ONE) REFERENCES PONE (ID_FIRST_ONE, ID_SECOND_ONE) ON DELETE CASCADE, CONSTRAINT PTWO_FK02 FOREIGN KEY (ID_CHILD, ID_CHILD_TO_TWO) REFERENCES PTWO (ID_FIRST_TWO, ID_SECOND_TWO) )");
 
         importedKeys = meta.getImportedKeys(null, null, "CHILD");
 
@@ -1537,6 +1567,7 @@ public class DBMetaDataTest {
     }
 
     @Test
+    @DisabledInNativeImage // assertj Assumptions do not work in native-image tests
     public void version() throws Exception {
         assumeThat(Utils.getCompileOptions(conn))
                 .as("Can't check the version if not compiled by us")
@@ -1568,4 +1599,31 @@ public class DBMetaDataTest {
         assertThat(meta.getDatabaseMinorVersion()).as("db minor version").isEqualTo(minorVersion);
         assertThat(meta.getUserName()).as("user name").isNull();
     }
+
+    @Nested
+    class SqliteSchema {
+        @ParameterizedTest
+        @ValueSource(strings = {"sqlite_schema", "sqlite_master"})
+        public void getImportedKeys(String table) throws SQLException {
+            ResultSet importedKeys = meta.getImportedKeys(null, null, table);
+
+            assertThat(importedKeys.next()).isFalse();
+        }
+
+        @ParameterizedTest
+        @ValueSource(strings = {"sqlite_schema", "sqlite_master"})
+        public void getExportedKeys(String table) throws SQLException {
+            ResultSet exportedKeys = meta.getExportedKeys(null, null, table);
+
+            assertThat(exportedKeys.next()).isFalse();
+        }
+
+        @ParameterizedTest
+        @ValueSource(strings = {"sqlite_schema", "sqlite_master"})
+        public void getPrimaryKeys(String table) throws SQLException {
+            ResultSet primaryKeys = meta.getPrimaryKeys(null, null, table);
+
+            assertThat(primaryKeys.next()).isFalse();
+        }
+    }
 }
