@@ -13,10 +13,8 @@
  *--------------------------------------------------------------------------*/
 package org.sqlite;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.sql.Connection;
 import java.sql.SQLException;
@@ -36,26 +34,24 @@ public class SQLiteConnectionPoolDataSourceTest {
         PooledConnection pooledConn = ds.getPooledConnection();
 
         Connection handle = pooledConn.getConnection();
-        assertFalse(handle.isClosed());
-        assertTrue(handle.createStatement().execute("select 1"));
+        assertThat(handle.isClosed()).isFalse();
+        assertThat(handle.createStatement().execute("select 1")).isTrue();
 
         Connection handle2 = pooledConn.getConnection();
-        assertTrue(handle.isClosed());
-        try {
-            handle.createStatement().execute("select 1");
-            fail();
-        } catch (SQLException e) {
-            assertEquals("Connection is closed", e.getMessage());
-        }
+        assertThat(handle.isClosed()).isTrue();
+        Connection finalHandle = handle;
+        assertThatThrownBy(() -> finalHandle.createStatement().execute("select 1"))
+                .isInstanceOf(SQLException.class)
+                .hasMessage("Connection is closed");
 
-        assertTrue(handle2.createStatement().execute("select 1"));
+        assertThat(handle2.createStatement().execute("select 1")).isTrue();
         handle2.close();
 
         handle = pooledConn.getConnection();
-        assertTrue(handle.createStatement().execute("select 1"));
+        assertThat(handle.createStatement().execute("select 1")).isTrue();
 
         pooledConn.close();
-        assertTrue(handle.isClosed());
+        assertThat(handle.isClosed()).isTrue();
     }
 
     @Disabled
