@@ -1,8 +1,6 @@
 package org.sqlite;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.sql.Connection;
@@ -27,8 +25,6 @@ public class SavepointTest {
     private Connection conn1, conn2;
     private Statement stat1, stat2;
 
-    boolean done = false;
-
     @BeforeAll
     public static void forName() throws Exception {
         System.out.println(
@@ -68,24 +64,24 @@ public class SavepointTest {
         stat1.executeUpdate("create table trans (c1);");
         conn1.setSavepoint();
 
-        assertEquals(1, stat1.executeUpdate("insert into trans values (4);"));
+        assertThat(stat1.executeUpdate("insert into trans values (4);")).isEqualTo(1);
 
         // transaction not yet commited, conn1 can see, conn2 can not
         rs = stat1.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(1, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(1);
         rs.close();
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(0, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(0);
         rs.close();
 
         conn1.commit();
 
         // all connects can see data
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(1, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(1);
         rs.close();
     }
 
@@ -99,13 +95,13 @@ public class SavepointTest {
         stat1.executeUpdate("insert into trans values (3);");
 
         rs = stat1.executeQuery(select);
-        assertTrue(rs.next());
+        assertThat(rs.next()).isTrue();
         rs.close();
 
         conn1.rollback(sp);
 
         rs = stat1.executeQuery(select);
-        assertFalse(rs.next());
+        assertThat(rs.next()).isFalse();
         rs.close();
     }
 
@@ -152,13 +148,13 @@ public class SavepointTest {
 
         // conn1 can see (1+...+7), conn2 can see (1+...+5)
         rs = stat1.executeQuery("select sum(c1) from t;");
-        assertTrue(rs.next());
-        assertEquals(1 + 2 + 3 + 4 + 5 + 6 + 7, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(1 + 2 + 3 + 4 + 5 + 6 + 7);
         rs.close();
 
         rs = stat2.executeQuery("select sum(c1) from t;");
-        assertTrue(rs.next());
-        assertEquals(1 + 2 + 3 + 4 + 5, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(1 + 2 + 3 + 4 + 5);
         rs.close();
     }
 
@@ -170,37 +166,37 @@ public class SavepointTest {
         stat1.executeUpdate("create table trans (c1);");
 
         Savepoint outerSP = conn1.setSavepoint("outer_sp");
-        assertEquals(1, stat1.executeUpdate("insert into trans values (4);"));
+        assertThat(stat1.executeUpdate("insert into trans values (4);")).isEqualTo(1);
 
         // transaction not yet commited, conn1 can see, conn2 can not
         rs = stat1.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(1, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(1);
         rs.close();
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(0, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(0);
         rs.close();
 
         Savepoint innerSP = conn1.setSavepoint("inner_sp");
-        assertEquals(1, stat1.executeUpdate("insert into trans values (5);"));
+        assertThat(stat1.executeUpdate("insert into trans values (5);")).isEqualTo(1);
 
         // transaction not yet commited, conn1 can see, conn2 can not
         rs = stat1.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(2, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(2);
         rs.close();
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(0, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(0);
         rs.close();
 
         // releasing an inner savepoint, statements are still wrapped by the outer savepoint
         conn1.releaseSavepoint(innerSP);
 
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(0, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(0);
         rs.close();
 
         // releasing the outer savepoint is like a commit
@@ -208,8 +204,8 @@ public class SavepointTest {
 
         // all connects can see SP1 data
         rs = stat2.executeQuery(countSql);
-        assertTrue(rs.next());
-        assertEquals(2, rs.getInt(1));
+        assertThat(rs.next()).isTrue();
+        assertThat(rs.getInt(1)).isEqualTo(2);
         rs.close();
     }
 }
